# Jrn Walter https://www.der-windows-papst.de
# Netzwerkkarte neu starten und Event-Log schreiben

# Funktionen
function Write-EventLogEntry {
    param(
        [string]$Message,
        [string]$LogName = "Application",
        [string]$Source = "NetworkAdapterRestartScript",
        [int]$EventID = 1999,
        [string]$EntryType = "Information"
    )
    
    # Quelle fr das Event-Log registrieren, falls nicht vorhanden
    if (-not [System.Diagnostics.EventLog]::SourceExists($Source)) {
        [System.Diagnostics.EventLog]::CreateEventSource($Source, $LogName)
    }

    # Ereignis in das Protokoll schreiben
    Write-EventLog -LogName $LogName -Source $Source -EventId $EventID -EntryType $EntryType -Message $Message
}

# Adaptername anpassen
$AdapterName = "Internet" # Netzwerkkartenname hier anpassen

# Adapter deaktivieren
Write-Host "Deaktiviere die Netzwerkkarte: $AdapterName"
try {
    Disable-NetAdapter -Name $AdapterName -Confirm:$false -ErrorAction Stop
    Write-EventLogEntry -Message "Netzwerkkarte '$AdapterName' wurde erfolgreich deaktiviert." -EntryType "Information"
    Write-Host "Netzwerkkarte wurde deaktiviert."
} catch {
    Write-EventLogEntry -Message "Fehler beim Deaktivieren der Netzwerkkarte '$AdapterName': $_" -EntryType "Error"
    Write-Host "Fehler beim Deaktivieren der Netzwerkkarte: $_"
    exit 1
}

# Adapter aktivieren
Start-Sleep -Seconds 5
Write-Host "Aktiviere die Netzwerkkarte: $AdapterName"
try {
    Enable-NetAdapter -Name $AdapterName -Confirm:$false -ErrorAction Stop
    Write-EventLogEntry -Message "Netzwerkkarte '$AdapterName' wurde erfolgreich aktiviert." -EntryType "Information"
    Write-Host "Netzwerkkarte wurde aktiviert."
} catch {
    Write-EventLogEntry -Message "Fehler beim Aktivieren der Netzwerkkarte '$AdapterName': $_" -EntryType "Error"
    Write-Host "Fehler beim Aktivieren der Netzwerkkarte: $_"
    exit 1
}

Write-Host "Neustart der Netzwerkkarte abgeschlossen."
Write-EventLogEntry -Message "Netzwerkkarte '$AdapterName' wurde erfolgreich neu gestartet." -EntryType "Information"
